#define FMT_UNKNOWN (-1)
#define HTMLX  0	/* HTML hex numeric */
#define HTMLD  1
#define SGMLX  2
#define SGMLD  3
#define BSLU   4
#define BSLX   5   /* Tcl hex number as opposed to character code  */ 
#define STDX   6
#define CLSX   7
#define RAWX   8
#define BSLXB  9
#define ABUX   10
#define JUUX   11
#define JuUX   12
#define UPLX   13
#define XQ     14
#define BSLUD  15
#define PERLV  16
#define DOLLAR 17
#define PSPT   18
#define CLR    19
#define ADA    20
#define HDML   21
#define BYTEO  22
#define BYTED  23
#define BYTEH  24
#define OOXML  25
#define PCTUX  26
#define CHENT  27	/* Used only by ascii2uni */
#define IFMT   28
#define JFMT   29
#define KFMT   30
#define APACHE 31
#define UTF8ANGLE 32




